{ config, lib, pkgs, ... }:
{
  imports = [ ./nginx ];

  config = lib.mkIf config.services.forgejo.enable {
    services.forgejo = {
      package = pkgs.forgejo;
      lfs.enable = true;
      settings = {
        server = {
          DOMAIN = "git.${config.vars.primeDomain}";
          ROOT_URL = "https://${config.services.forgejo.settings.server.DOMAIN}:443";
          HTTP_PORT = 3110;
          SSH_PORT = 2299;
          START_SSH_SERVER = true;
        };
        mailer = {
          ENABLED = true;
          SMTP_ADDR = "mx.${config.vars.mailDomain}";
          FROM = "NixFox Git <noreply@${config.vars.primeDomain}>";
          USER = "noreply@${config.vars.primeDomain}";
          PASSWD = config.secrets.mailPass.nixfoxNoReply;
          PROTOCOL = "smtps";
        };
        service = {
          REGISTER_EMAIL_CONFIRM = true;
          DISABLE_REGISTRATION = true;
        };
        ui.DEFAULT_THEME = "forgejo-dark";
      };
    };

    networking.firewall.allowedTCPPorts = [ 2299 ];

    services.cloudflare-dyndns.domains = [ config.services.forgejo.settings.server.DOMAIN ];

    environment.persistence."/persist".directories = [ "/var/lib/forgejo" ];
  };
}
