{ config, lib, ... }:
{
  imports = [ ./nginx ];

  config = lib.mkIf config.services.matrix-synapse.enable {
    services.matrix-synapse = {
      settings = {
        server_name = "${config.vars.primeDomain}";
        public_baseurl = "https://matrix.${config.vars.primeDomain}";
        suppress_key_server_warning = true;

        # Email notifications about account status
        email = {
          smtp_host = "mx.${config.vars.mailDomain}";
          smtp_user = "noreply@${config.vars.primeDomain}";
          smtp_pass = config.secrets.mailPass.nixfoxNoReply;
          notif_from = "NixFox Matrix <noreply@${config.vars.primeDomain}>";
          enable_tls = true;
          smtp_port = 587;
          require_transport_security = true;
        };

        # Disable registration without email
        registrations_require_3pid = [ "email" ];

        # Set the type of database
        database.name = "sqlite3";

        # Allow account registration
        enable_registration = true;

        # General settings
        max_upload_size = "60M";
        burst_count = 15;
      };
    };

    environment.persistence."/persist".directories = [ "/var/lib/matrix-synapse" ];
  };
}
