{ config, lib, pkgs, ... }:
{
  imports = [
    ./nginx
    ./user
  ];

  config = lib.mkIf config.services.nextcloud.enable {
    services.nextcloud = {
      package = pkgs.nextcloud31;
      hostName = "files.${config.vars.primeDomain}";
      https = true;
      config = {
        adminuser = "admin";
        adminpassFile = "${pkgs.writeText "initial" config.secrets.initialPass}";
        dbtype = "sqlite";
      };
      settings = {
        trusted_proxies = [ "127.0.0.1" ];
        trusted_domains = [ config.services.nextcloud.hostName ];
        overwriteprotocol = "https";
        mail_smtphost = "mx.${config.vars.mailDomain}";
        mail_domain = "${config.vars.primeDomain}";
        mail_from_address = "noreply";
        mail_smtpauth = "true";
        mail_smtpname = "noreply@${config.vars.primeDomain}";
        mail_smtppassword = config.secrets.mailPass.nixfoxNoReply;
        mail_smtpmode = "smtp";
        mail_smtpport = 587;
      };
    };
    environment.persistence."/persist".directories = [ "/var/lib/nextcloud" ];
  };
}
